@@ -1,8 +1,8 @@
 import pendulum
-from dagster.cli.workspace.dynamic_workspace import DynamicWorkspace
 from dagster.core.definitions.run_request import JobType
 from dagster.core.host_representation.grpc_server_registry import ProcessGrpcServerRegistry
 from dagster.core.scheduler.job import JobState, JobStatus
+from dagster.core.workspace.dynamic_workspace import DynamicWorkspace
 from dagster.daemon import get_default_daemon_logger
 from dagster.daemon.sensor import execute_sensor_iteration
 from dagster_graphql.test.utils import (
@@ -28,12 +28,13 @@ query SensorsQuery($repositorySelector: RepositorySelector!) {
     }
     ... on Sensors {
       results {
-        id
         name
-        pipelineName
-        solidSelection
+        targets {
+          pipelineName
+          solidSelection
+          mode
+        }
         description
-        mode
         minIntervalSeconds
         sensorState {
           status
@@ -69,11 +70,12 @@ query SensorQuery($sensorSelector: SensorSelector!) {
       stack
     }
     ... on Sensor {
-      id
       name
-      pipelineName
-      solidSelection
-      mode
+      targets {
+        pipelineName
+        solidSelection
+        mode
+      }
       minIntervalSeconds
       nextTick {
         timestamp
@@ -152,7 +154,7 @@ mutation($jobOriginId: String!) {
       stack
     }
     ... on StopSensorMutationResult {
-      jobState {
+      instigationState {
         status
       }
     }
@@ -221,7 +223,7 @@ class TestSensorMutations(ExecutingGraphQLContextTestMatrix):
             variables={"jobOriginId": job_origin_id},
         )
         assert result.data
-        assert result.data["stopSensor"]["jobState"]["status"] == JobStatus.STOPPED.value
+        assert result.data["stopSensor"]["instigationState"]["status"] == JobStatus.STOPPED.value
 
 
 def test_sensor_next_ticks(graphql_context):
